Avro Schema Converter
======================

``inverter`` provides converter from ``dataclass`` to `Avro Schema  <http://avro.apache.org/docs/current/spec.html>`_ .

.. autofunction:: inverter.dc2avsc.convert